@@ -1,11 +1,10 @@
 package Tapper::CLI::Cobbler;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::CLI::Cobbler::VERSION = '4.1.7';
+$Tapper::CLI::Cobbler::VERSION = '5.0.0';
 use 5.010;
-use warnings;
-use strict;
 
-use Tapper::Cmd::Cobbler;
+use strict;
+use warnings;
 
 
 
@@ -31,7 +30,7 @@ sub host_new
         $options{default} = $c->options->{default};
         $options{mac}     = $c->options->{mac};
 
-
+        require Tapper::Cmd::Cobbler;
         my $cmd = Tapper::Cmd::Cobbler->new();
         my $output = $cmd->host_new($name, \%options);
         return $output if $output;
@@ -59,6 +58,7 @@ sub host_del
         }
         my $name    = $c->options->{name};
 
+        require Tapper::Cmd::Cobbler;
         my $cmd = Tapper::Cmd::Cobbler->new();
         my $output = $cmd->host_del($name);
         die $output if $output;
@@ -83,6 +83,7 @@ sub host_list
                 exit -1;
         }
 
+        require Tapper::Cmd::Cobbler;
         my $cmd = Tapper::Cmd::Cobbler->new();
         my @output = $cmd->host_list();
         print join "\n",@output;
@@ -155,7 +156,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
