@@ -1,6 +1,6 @@
 package Tapper::CLI::DbDeploy::Command::saveschema;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::CLI::DbDeploy::Command::saveschema::VERSION = '4.1.7';
+$Tapper::CLI::DbDeploy::Command::saveschema::VERSION = '5.0.0';
 use 5.010;
 
 use strict;
@@ -51,9 +51,9 @@ sub validate_args {
                 say "Missing argument --db\n";
                 $ok = 0;
         }
-        elsif (not $opt->{db} =~ /^ReportsDB|TestrunDB$/)
+        elsif (not $opt->{db} = 'TestrunDB')
         {
-                say "Wrong DB name '".$opt->{db}."' (must be ReportsDB or TestrunDB)";
+                say "Wrong DB name '".$opt->{db}."' (must be TestrunDB)";
                 $ok = 0;
         }
 
@@ -85,7 +85,7 @@ sub run
                                   );
 }
 
-# perl -Ilib bin/tapper-db-deploy saveschema --db=ReportsDB
+# perl -Ilib bin/tapper-db-deploy saveschema --db=TestrunDB
 
 1;
 
@@ -105,7 +105,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
