@@ -1,6 +1,6 @@
 package Tapper::CLI::DbDeploy::Command::upgrade;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::CLI::DbDeploy::Command::upgrade::VERSION = '4.1.7';
+$Tapper::CLI::DbDeploy::Command::upgrade::VERSION = '5.0.0';
 use 5.010;
 
 use strict;
@@ -27,7 +27,7 @@ sub opt_spec {
 }
 
 # aktuelle Version und Diff erzeugen zur gewünschten vorherigen
-# perl -Ilib -MTapper::Schema::ReportsDB -e 'Tapper::Schema::ReportsDB->connect("DBI:SQLite:foo")->create_ddl_dir([qw/MySQL SQLite PostgreSQL/], undef, "upgrades/", "2.010012") or die'
+# perl -Ilib -MTapper::Schema::ReportsDB -e 'Tapper::Schema::TestrunDB->connect("DBI:SQLite:foo")->create_ddl_dir([qw/MySQL SQLite PostgreSQL/], undef, "upgrades/", "2.010012") or die'
 
 sub abstract {
         'Upgrade a database schema'
@@ -58,9 +58,9 @@ sub validate_args {
                 say "Missing argument --db\n";
                 $ok = 0;
         }
-        elsif (not $opt->{db} =~ /^ReportsDB|TestrunDB$/)
+        elsif (not $opt->{db} = 'TestrunDB')
         {
-                say "Wrong DB name '".$opt->{db}."' (must be ReportsDB or TestrunDB)";
+                say "Wrong DB name '".$opt->{db}."' (must be TestrunDB)";
                 $ok = 0;
         }
 
@@ -84,7 +84,7 @@ sub run
 }
 
 
-# perl -Ilib bin/tapper-db-deploy upgrade --db=ReportsDB
+# perl -Ilib bin/tapper-db-deploy upgrade --db=TestrunDB
 
 1;
 
@@ -104,7 +104,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
