@@ -1,13 +1,10 @@
 package Tapper::CLI::Notification;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::CLI::Notification::VERSION = '4.1.7';
+$Tapper::CLI::Notification::VERSION = '5.0.0';
 use 5.010;
 use warnings;
 use strict;
 
-use YAML::XS;
-use Tapper::Cmd::Notification;
-
 
 sub notificationnew
 {
@@ -23,13 +20,15 @@ sub notificationnew
                 say STDERR "        --verbose          Be chatty";
                 say STDERR "        --quiet            Stay silent when notification was added";
                 say STDERR "        --help             print this help message and exit";
-                exit -1;
+                return;
         }
 
+        require Tapper::Cmd::Notification;
         my $cmd = Tapper::Cmd::Notification->new();
         my $user = $c->options->{user};
 
         my @ids;
+        require YAML::XS;
         my @subscriptions =  YAML::XS::LoadFile($c->options->{file});
         foreach my $subscription (@subscriptions) {
                 if ($user) {
@@ -50,6 +49,10 @@ sub notificationnew
 sub notificationlist
 {
         my ($c) = @_;
+
+        require YAML::XS;
+        require Tapper::Cmd::Notification;
+
         my $cmd = Tapper::Cmd::Notification->new();
         my $subscription_result = $cmd->list();
         while (my $this_subscription = $subscription_result->next) {
@@ -74,11 +77,13 @@ sub notificationupdate
                 say STDERR "\n  Optional arguments:";
                 say STDERR "        --quiet            stay silent when notification was updated";
                 say STDERR "        --help             print this help message and exit";
-                exit -1;
+                return;
         }
 
+        require Tapper::Cmd::Notification;
         my $cmd = Tapper::Cmd::Notification->new();
 
+        require YAML::XS;
         my $subscription =  YAML::XS::LoadFile($c->options->{file});
         my $id = $cmd->update($c->options->{id}, $subscription);
 
@@ -101,9 +106,10 @@ sub notificationdel
                 say STDERR "\n  Optional arguments:";
                 say STDERR "        --quiet            Stay silent when deleting succeeded";
                 say STDERR "        --help             print this help message and exit";
-                exit -1;
+                return;
         }
 
+        require Tapper::Cmd::Notification;
         my $cmd = Tapper::Cmd::Notification->new();
 
         my $id = $cmd->del($c->options->{id});
@@ -124,7 +130,14 @@ sub setup
         $c->register('notification-update', \&notificationupdate, 'Update an existing notification subscription');
         $c->register('notification-del', \&notificationdel, 'Delete an existing notification subscription');
         if ($c->can('group_commands')) {
-                $c->group_commands('Notification commands', 'notification-add', 'notification-new', 'notification-list', 'notification-update', 'notification-del');
+                $c->group_commands(
+                    'Notification commands',
+                        'notification-add',
+                        'notification-new',
+                        'notification-list',
+                        'notification-update',
+                        'notification-del',
+                );
         }
         return;
 }
@@ -200,7 +213,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
