@@ -1,13 +1,10 @@
 package Tapper::CLI::Schema;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::CLI::Schema::VERSION = '4.1.7';
+$Tapper::CLI::Schema::VERSION = '5.0.0';
 use 5.010;
 use warnings;
 use strict;
 
-use Tapper::Model 'model';
-use Compress::Bzip2;
-
 
 sub zipfiles
 {
@@ -21,7 +18,10 @@ sub zipfiles
                 say STDERR "\t--help\t\tprint this help message and exit";
                 exit -1;
         }
-        my $uncompressed_files  = model('ReportsDB')->resultset('ReportFile')->search({is_compressed => 0});
+
+        require Compress::Bzip2;
+        require Tapper::Model;
+        my $uncompressed_files  = Tapper::Model::model('TestrunDB')->resultset('ReportFile')->search({is_compressed => 0});
         while (my $file = $uncompressed_files->next) {
                 my $compressed;
                 eval { $compressed = memBzip( $file->filecontent) };
@@ -92,7 +92,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
