@@ -1,13 +1,11 @@
 package Tapper::CLI::User;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::CLI::User::VERSION = '4.1.7';
+$Tapper::CLI::User::VERSION = '5.0.0';
 use 5.010;
 use warnings;
 use strict;
 
 use Try::Tiny;
-use YAML::XS;
-use Tapper::Cmd::User;
 use UNIVERSAL;
 
 
@@ -15,6 +13,9 @@ sub get_contacts
 {
         my ($contacts) = @_;
         my @contacts;
+
+        require YAML::XS;
+
         foreach my $contact (@{$contacts || []}) {
                 if ($contact !~ m/\n/ and -e $contact) {
                         try {
@@ -60,6 +61,9 @@ sub usernew
         my $data;
         $data   = { login => $c->options->{login}, name => $c->options->{name} , contacts => \@contacts};
 
+        require YAML::XS;
+        require Tapper::Cmd::User;
+
         my $cmd = Tapper::Cmd::User->new();
         my $id  = $cmd->add($data);
         if (not $c->options->{quiet}) {
@@ -76,7 +80,7 @@ sub contactadd
         $c->getopt( 'contact|c=s@', 'login|l=s', 'quiet|q', 'help|?' );
 
         if ($c->options->{help} or not $c->options->{contact} ) {
-                say STDERR "Usage: $0 conact-add [ --login=login ] [ --contact=YAML | --contact=filename ]* [ --quiet ]";
+                say STDERR "Usage: $0 contact-add [ --login=login ] [ --contact=YAML | --contact=filename ]* [ --quiet ]";
                 say STDERR "\n  Optional arguments:";
                 say STDERR "         --login           login name for the user (default is $ENV{USER})";
                 say STDERR "         --contact         contact information in YAML or name of a file containing this information (can be given multiple times)";
@@ -86,6 +90,8 @@ sub contactadd
         }
 
         my $login = $c->options->{login} || $ENV{USER};
+
+        require Tapper::Cmd::User;
         my $cmd = Tapper::Cmd::User->new();
 
         my @contacts = get_contacts($c->options->{contact});
@@ -93,6 +99,7 @@ sub contactadd
                 my $id  = $cmd->contact_add($login, $contact);
         }
 
+        require YAML::XS;
         if (not $c->options->{quiet}) {
                 my @users = $cmd->list({login => $login});
                 print YAML::XS::Dump($users[0]);
@@ -105,6 +112,10 @@ sub contactadd
 sub userlist
 {
         my ($c) = @_;
+
+        require YAML::XS;
+        require Tapper::Cmd::User;
+
         my $cmd = Tapper::Cmd::User->new();
         my @users = $cmd->list();
         foreach my $user (@users) {
@@ -130,8 +141,10 @@ sub userupdate
                 exit -1;
         }
 
+        require Tapper::Cmd::User;
         my $cmd = Tapper::Cmd::User->new();
 
+        require YAML::XS;
         my $subscription =  YAML::XS::LoadFile($c->options->{file});
         my $id = $cmd->update($c->options->{id}, $subscription);
 
@@ -156,6 +169,7 @@ sub userdel
                 exit -1;
         }
 
+        require Tapper::Cmd::User;
         my $cmd = Tapper::Cmd::User->new();
 
         if ($c->options->{login}) {
@@ -278,7 +292,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
